/*
 * topological-hex, a program to compute combinatorial hexahedral meshes.
 *
 * Copyright (C) <2018> <Université catholique de Louvain (UCL), Belgique>
 *
 * List of the contributors to the development, description and complete
 * License: see LICENSE file.
 *
 * This program (topological-hex) is free software:
 * you can redistribute it and/or modify it under the terms
 * of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (see COPYING file).  If not,
 * see <http://www.gnu.org/licenses/>.
 */


#ifndef UTILS_H_
#define UTILS_H_

#include <stdint.h>

/**
 * @defgroup utils Utilities
 *
 * Contains compiler-specific definitions and macros.
 */

/**
 * @addtogroup utils
 * @{
 */

#define ALIGNMENT 32

#define ALIGNED __attribute__((aligned(32)))
#define ALIGNED16 __attribute__((aligned(16)))

/**
 * Returns the index of the least-significant bit set to 1 in a 64-bit
 * integer. The result may be undefined if i is equal to 0.
 */
static inline
uint32_t find_lsb64(uint64_t i) { return __builtin_ctzll(i); }

/**
 * Returns the index of the least-significant bit set to 1 in a 32-bit
 * integer. The result may be undefined if i is equal to 0.
 */
static inline
uint32_t find_lsb32(uint32_t i) { return __builtin_ctz(i); }

#define XTOKEN_PASTE(a, b) a##b

/**
 * Expands and concatenates two tokens.
 */
#define TOKEN_PASTE(a, b) XTOKEN_PASTE(a, b)

/**
 * @}
 */

#endif
